player = {}

function player.load(x, y)
	player.width = 32
	player.height = 32

	player.x = x
	player.y = y

	player.xVel = 0
	player.yVel = 0

	player.runSpeed = 200
	player.jumpSpeed = -400

	player.onground = false

end

function player.update(dt)
	
	local originToTest = { x = player.x + player.xVel * dt , y = player.y + player.yVel * dt }

	local colPoints = { 
		ceilingTopLeft     =  { x = originToTest.x - tileSize/2 + 1, y = originToTest.y - tileSize/2 },
		leftTopLeft        =  { x = originToTest.x - tileSize/2,     y = originToTest.y - tileSize/2 + 1 },
		ceilingTopRight    =  { x = originToTest.x + tileSize/2 - 1, y = originToTest.y - tileSize/2 },
		rightTopRight      =  { x = originToTest.x + tileSize/2,     y = originToTest.y - tileSize/2 + 1 },
		floorBottomLeft    =  { x = originToTest.x - tileSize/2 + 1, y = originToTest.y + tileSize/2 },
		leftBottomLeft     =  { x = originToTest.x - tileSize/2,     y = originToTest.y + tileSize/2 - 1 },
		floorBottomRight   =  { x = originToTest.x + tileSize/2 - 1, y = originToTest.y + tileSize/2 },
		rightBottomRight   =  { x = originToTest.x + tileSize/2,     y = originToTest.y + tileSize/2 - 1 }
		
	}

	-- ceiling collision
	if level.testTile(colPoints.ceilingTopLeft.x, colPoints.ceilingTopLeft.y) or level.testTile(colPoints.ceilingTopRight.x, colPoints.ceilingTopRight.y) then
		player.yVel = 0
		player.y = player.y + 1*dt
		print("ceiling collision: ", colPoints.ceilingTopLeft.x, colPoints.ceilingTopLeft.y)
	end
	-- floor collision
	if level.testTile(colPoints.floorBottomLeft.x, colPoints.floorBottomLeft.y) or level.testTile(colPoints.floorBottomRight.x, colPoints.floorBottomRight.y) then
		player.yVel = 0
		player.onground = true
		player.y = player.y - 1*dt
	end
	-- left collision
	if level.testTile(colPoints.leftTopLeft.x, colPoints.leftTopLeft.y) or level.testTile(colPoints.leftBottomLeft.x, colPoints.leftBottomLeft.y) then
		player.xVel = 0
		player.x = player.x + 1*dt
	end
	-- right collision
	if level.testTile(colPoints.rightTopRight.x, colPoints.rightTopRight.y) or level.testTile(colPoints.rightBottomRight.x, colPoints.rightBottomRight.y) then
		player.xVel = 0
		player.x = player.x - 1*dt
	end
	-- falling
	if not(level.testTile(colPoints.floorBottomLeft.x, colPoints.floorBottomLeft.y) or level.testTile(colPoints.floorBottomRight.x, colPoints.floorBottomRight.y)) then
		player.onground = false
	end

	player.x = player.x + player.xVel * dt
	player.y = player.y + player.yVel * dt

	player.yVel = player.yVel + gravity * dt
	

	k = love.keyboard
	if k.isDown("left") then player.move(-player.runSpeed) end
	if k.isDown("right") then player.move(player.runSpeed) end
	if not(k.isDown("left")) and not(k.isDown("right")) then player.stop() end
	
	if k.isDown("up") then player.jump(player.jumpSpeed) end
	if not(k.isDown("up")) then yVel = 0 end

	if k.isDown("lshift") then gravity = 0 end
	if not(k.isDown("lshift")) then gravity = 1000 end
end

function player.move(speed)
	player.xVel = speed
end

function player.jump(speed)
	if player.onground then 
		player.yVel = speed
		player.onground = false
	end
end

function player.stop()
	player.xVel = 0
end

function player.draw()

	love.graphics.setColor(0, 153, 153)
	love.graphics.rectangle("fill", player.x-player.width/2, player.y-player.height/2, player.width, player.height)

end

